/*
 * DVB USB Linux driver for Afatech AF9015 DVB-T USB2.0 receiver
 *
 * Copyright (C) 2007 Antti Palosaari <crope@iki.fi>
 *
 * Thanks to Afatech who kindly provided information.
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifndef _AF9013_PRIV_
#define _AF9013_PRIV_

#define LOG_PREFIX "af9013"
extern int debug;

#define dprintk(var, level, args...) \
	    do { if ((var & level)) { printk(args); } } while (0)

#define debug_dump(b, l, func) {\
	int loop_; \
	for (loop_ = 0; loop_ < l; loop_++) func("%02x ", b[loop_]); \
	func("\n");\
}

#define deb_info(args...) dprintk(debug, 0x01, args)

#undef err
#define err(f, arg...)  printk(KERN_ERR     LOG_PREFIX": " f "\n" , ## arg)
#undef info
#define info(f, arg...) printk(KERN_INFO    LOG_PREFIX": " f "\n" , ## arg)
#undef warn
#define warn(f, arg...) printk(KERN_WARNING LOG_PREFIX": " f "\n" , ## arg)

struct regdesc {
	u16 addr;
	u8  pos;
	u8  len;
	u8  val;
};

/* taken from driver:
Driver release date : 2007/11/08
Version : v7.7.4.1
Download: AFAdriver9015-7.7.4.1.WHQL.zip

[crope@localhost Files]$ md5sum AF15BDA.sys
3cd15ebaa1d68bc18ce14a26683bc1ec  AF15BDA.sys
*/

/*
[crope@localhost Files]$ hexdump -s 0x0024980 -n 450 \
-e '1/2 "{ 0x%04x, " 2/1 "0x%02x, " 1/1 " 0x%02x }, " 1/1 "\n"' AF15BDA.sys
*/
static struct regdesc ofsm_init[] = {
{ 0xd73a, 0x00, 0x08, 0xa1 },
{ 0xd73b, 0x00, 0x08, 0x1f },
{ 0xd73c, 0x04, 0x04, 0x0a },
{ 0xd732, 0x03, 0x01, 0x00 },
{ 0xd731, 0x04, 0x02, 0x03 },
{ 0xd73d, 0x07, 0x01, 0x01 },
{ 0xd740, 0x00, 0x01, 0x00 },
{ 0xd740, 0x01, 0x01, 0x00 },
{ 0xd740, 0x02, 0x01, 0x00 },
{ 0xd740, 0x03, 0x01, 0x01 },
{ 0xd3c1, 0x04, 0x01, 0x01 },
{ 0xd3a2, 0x00, 0x08, 0x00 },
{ 0xd3a3, 0x00, 0x08, 0x04 },
{ 0xd305, 0x00, 0x08, 0x32 },
{ 0xd306, 0x00, 0x08, 0x10 },
{ 0xd304, 0x00, 0x08, 0x04 },
{ 0x9112, 0x00, 0x01, 0x01 },
{ 0x911d, 0x00, 0x01, 0x01 },
{ 0x911a, 0x00, 0x01, 0x01 },
{ 0x911b, 0x00, 0x01, 0x01 },
{ 0x9bce, 0x00, 0x04, 0x02 },
{ 0x9116, 0x00, 0x01, 0x01 },
{ 0x9bd1, 0x00, 0x01, 0x01 },
{ 0xd2e0, 0x00, 0x08, 0xd0 },
{ 0xd2e9, 0x00, 0x04, 0x0d },
{ 0xd38c, 0x00, 0x08, 0xfc },
{ 0xd38d, 0x00, 0x08, 0x00 },
{ 0xd38e, 0x00, 0x08, 0x7e },
{ 0xd38f, 0x00, 0x08, 0x00 },
{ 0xd390, 0x00, 0x08, 0x2f },
{ 0xd145, 0x04, 0x01, 0x01 },
{ 0xd1a9, 0x04, 0x01, 0x01 },
{ 0xd158, 0x05, 0x03, 0x01 },
{ 0xd159, 0x00, 0x06, 0x06 },
{ 0xd167, 0x00, 0x08, 0x00 },
{ 0xd168, 0x00, 0x04, 0x07 },
{ 0xd1c3, 0x05, 0x03, 0x00 },
{ 0xd1c4, 0x00, 0x06, 0x00 },
{ 0xd1c5, 0x00, 0x07, 0x10 },
{ 0xd1c6, 0x00, 0x03, 0x02 },
{ 0xd080, 0x02, 0x05, 0x03 },
{ 0xd081, 0x04, 0x04, 0x09 },
{ 0xd098, 0x04, 0x04, 0x0f },
{ 0xd098, 0x00, 0x04, 0x03 },
{ 0xdbc0, 0x03, 0x01, 0x01 },
{ 0xdbc0, 0x04, 0x01, 0x01 },
{ 0xdbc7, 0x00, 0x08, 0x08 },
{ 0xdbc8, 0x04, 0x04, 0x00 },
{ 0xdbc9, 0x00, 0x05, 0x01 },
{ 0xd280, 0x00, 0x08, 0xe0 },
{ 0xd281, 0x00, 0x08, 0xff },
{ 0xd282, 0x00, 0x08, 0xff },
{ 0xd283, 0x00, 0x08, 0xc3 },
{ 0xd284, 0x00, 0x08, 0xff },
{ 0xd285, 0x00, 0x04, 0x01 },
{ 0xd0f0, 0x00, 0x07, 0x1a },
{ 0xd0f1, 0x04, 0x01, 0x01 },
{ 0xd0f2, 0x00, 0x08, 0x0c },
{ 0xd103, 0x00, 0x04, 0x08 },
{ 0xd0f8, 0x00, 0x07, 0x20 },
{ 0xd111, 0x05, 0x01, 0x00 },
{ 0xd111, 0x06, 0x01, 0x00 },
{ 0x910b, 0x00, 0x08, 0x0a },
{ 0x9115, 0x00, 0x08, 0x02 },
{ 0x910c, 0x00, 0x08, 0x02 },
{ 0x910d, 0x00, 0x08, 0x08 },
{ 0x910e, 0x00, 0x08, 0x0a },
{ 0x9bf6, 0x00, 0x08, 0x06 },
{ 0x9bf8, 0x00, 0x08, 0x02 },
{ 0x9bf7, 0x00, 0x08, 0x05 },
{ 0x9bf9, 0x00, 0x08, 0x0f },
{ 0x9bfc, 0x00, 0x08, 0x13 },
{ 0x9bd3, 0x00, 0x08, 0xff },
{ 0x9bbe, 0x00, 0x01, 0x01 },
{ 0x9bcc, 0x00, 0x01, 0x01 },
};

/* MT2060 tuner init
[crope@localhost Files]$ hexdump -s 0x0023af0 -n 432 \
-e '1/2 "{ 0x%04x, " 2/1 "0x%02x, " 1/1 " 0x%02x }, " 1/1 "\n"' AF15BDA.sys
*/
static struct regdesc mt2060_tuner_init[] = {
{ 0x9bd5, 0x00, 0x08, 0x01 },
{ 0x9bd6, 0x00, 0x08, 0x07 },
{ 0xd1a0, 0x01, 0x01, 0x01 },
{ 0xd000, 0x00, 0x01, 0x01 },
{ 0xd000, 0x01, 0x01, 0x00 },
{ 0xd001, 0x01, 0x01, 0x01 },
{ 0xd001, 0x00, 0x01, 0x00 },
{ 0xd001, 0x05, 0x01, 0x00 },
{ 0xd002, 0x00, 0x05, 0x19 },
{ 0xd003, 0x00, 0x05, 0x1a },
{ 0xd004, 0x00, 0x05, 0x19 },
{ 0xd005, 0x00, 0x05, 0x1a },
{ 0xd00e, 0x00, 0x05, 0x10 },
{ 0xd00f, 0x00, 0x03, 0x04 },
{ 0xd00f, 0x03, 0x03, 0x05 },
{ 0xd010, 0x00, 0x03, 0x04 },
{ 0xd010, 0x03, 0x03, 0x05 },
{ 0xd016, 0x04, 0x04, 0x03 },
{ 0xd01f, 0x00, 0x06, 0x0a },
{ 0xd020, 0x00, 0x06, 0x0a },
{ 0x9bda, 0x00, 0x08, 0x00 },
{ 0x9be3, 0x00, 0x08, 0x00 },
{ 0x9bbe, 0x00, 0x01, 0x00 },
{ 0x9bcc, 0x00, 0x01, 0x00 },
{ 0x9bb9, 0x00, 0x08, 0x75 },
{ 0x9bcd, 0x00, 0x08, 0x24 },
{ 0x9bff, 0x00, 0x08, 0x30 },
{ 0xd015, 0x00, 0x08, 0x46 },
{ 0xd016, 0x00, 0x01, 0x00 },
{ 0xd044, 0x00, 0x08, 0x46 },
{ 0xd045, 0x00, 0x01, 0x00 },
{ 0xd008, 0x00, 0x08, 0x0f },
{ 0xd009, 0x00, 0x02, 0x02 },
{ 0xd006, 0x00, 0x08, 0x32 },
{ 0xd007, 0x00, 0x02, 0x01 },
{ 0xd00c, 0x00, 0x08, 0x36 },
{ 0xd00d, 0x00, 0x02, 0x03 },
{ 0xd00a, 0x00, 0x08, 0x35 },
{ 0xd00b, 0x00, 0x02, 0x01 },
{ 0x9bc7, 0x00, 0x08, 0x07 },
{ 0x9bc8, 0x00, 0x08, 0x90 },
{ 0x9bc3, 0x00, 0x08, 0x0f },
{ 0x9bc4, 0x00, 0x08, 0x02 },
{ 0x9bc5, 0x00, 0x08, 0x36 },
{ 0x9bc6, 0x00, 0x08, 0x03 },
{ 0x9bba, 0x00, 0x08, 0xc9 },
{ 0x9bc9, 0x00, 0x08, 0x79 },
{ 0xd011, 0x00, 0x08, 0x10 },
{ 0xd012, 0x00, 0x02, 0x01 },
{ 0xd013, 0x00, 0x08, 0x45 },
{ 0xd014, 0x00, 0x02, 0x03 },
{ 0xd040, 0x00, 0x08, 0x98 },
{ 0xd041, 0x00, 0x02, 0x00 },
{ 0xd042, 0x00, 0x08, 0xcf },
{ 0xd043, 0x00, 0x02, 0x03 },
{ 0xd045, 0x01, 0x01, 0x00 },
{ 0x9bcf, 0x00, 0x01, 0x01 },
{ 0xd045, 0x02, 0x01, 0x01 },
{ 0xd04f, 0x00, 0x08, 0x9a },
{ 0xd050, 0x00, 0x01, 0x01 },
{ 0xd051, 0x00, 0x08, 0x5a },
{ 0xd052, 0x00, 0x01, 0x01 },
{ 0xd053, 0x00, 0x08, 0x50 },
{ 0xd054, 0x00, 0x08, 0x46 },
{ 0x9bd7, 0x00, 0x08, 0x0a },
{ 0x9bd8, 0x00, 0x08, 0x14 },
{ 0x9bd9, 0x00, 0x08, 0x08 },
{ 0x9bd0, 0x00, 0x08, 0xcc },
{ 0x9be4, 0x00, 0x08, 0xa0 },
{ 0x9bbd, 0x00, 0x08, 0x8e },
{ 0x9be2, 0x00, 0x08, 0x4d },
{ 0x9bee, 0x00, 0x01, 0x01 },
};

/* MXL500x tuner init
[crope@localhost Files]$ hexdump -s 0x000023fa0 -n 438 \
-e '1/2 "{ 0x%04x, " 2/1 "0x%02x, " 1/1 " 0x%02x }, " 1/1 "\n"' AF15BDA.sys
*/
static struct regdesc mxl5003_tuner_init[] = {
{ 0x9bd5, 0x00, 0x08, 0x01 },
{ 0x9bd6, 0x00, 0x08, 0x07 },
{ 0xd1a0, 0x01, 0x01, 0x01 },
{ 0xd000, 0x00, 0x01, 0x01 },
{ 0xd000, 0x01, 0x01, 0x00 },
{ 0xd001, 0x01, 0x01, 0x01 },
{ 0xd001, 0x00, 0x01, 0x00 },
{ 0xd001, 0x05, 0x01, 0x00 },
{ 0xd002, 0x00, 0x05, 0x19 },
{ 0xd003, 0x00, 0x05, 0x1a },
{ 0xd004, 0x00, 0x05, 0x19 },
{ 0xd005, 0x00, 0x05, 0x1a },
{ 0xd00e, 0x00, 0x05, 0x10 },
{ 0xd00f, 0x00, 0x03, 0x04 },
{ 0xd00f, 0x03, 0x03, 0x05 },
{ 0xd010, 0x00, 0x03, 0x04 },
{ 0xd010, 0x03, 0x03, 0x05 },
{ 0xd016, 0x04, 0x04, 0x03 },
{ 0xd01f, 0x00, 0x06, 0x0a },
{ 0xd020, 0x00, 0x06, 0x0a },
{ 0x9bda, 0x00, 0x08, 0x01 },
{ 0x9be3, 0x00, 0x08, 0x01 },
{ 0x9bbe, 0x00, 0x01, 0x01 },
{ 0x9bcc, 0x00, 0x01, 0x01 },
{ 0x9bb9, 0x00, 0x08, 0x00 },
{ 0x9bcd, 0x00, 0x08, 0x28 },
{ 0x9bff, 0x00, 0x08, 0x24 },
{ 0xd015, 0x00, 0x08, 0x40 },
{ 0xd016, 0x00, 0x01, 0x00 },
{ 0xd044, 0x00, 0x08, 0x40 },
{ 0xd045, 0x00, 0x01, 0x00 },
{ 0xd008, 0x00, 0x08, 0x0f },
{ 0xd009, 0x00, 0x02, 0x02 },
{ 0xd006, 0x00, 0x08, 0x73 },
{ 0xd007, 0x00, 0x02, 0x01 },
{ 0xd00c, 0x00, 0x08, 0xfa },
{ 0xd00d, 0x00, 0x02, 0x01 },
{ 0xd00a, 0x00, 0x08, 0xff },
{ 0xd00b, 0x00, 0x02, 0x01 },
{ 0x9bc7, 0x00, 0x08, 0x23 },
{ 0x9bc8, 0x00, 0x08, 0x55 },
{ 0x9bc3, 0x00, 0x08, 0x01 },
{ 0x9bc4, 0x00, 0x08, 0x02 },
{ 0x9bc5, 0x00, 0x08, 0xfa },
{ 0x9bc6, 0x00, 0x08, 0x01 },
{ 0x9bba, 0x00, 0x08, 0xff },
{ 0x9bc9, 0x00, 0x08, 0xff },
{ 0x9bd3, 0x00, 0x08, 0x95 },
{ 0xd011, 0x00, 0x08, 0x70 },
{ 0xd012, 0x00, 0x02, 0x01 },
{ 0xd013, 0x00, 0x08, 0xfb },
{ 0xd014, 0x00, 0x02, 0x01 },
{ 0xd040, 0x00, 0x08, 0x70 },
{ 0xd041, 0x00, 0x02, 0x01 },
{ 0xd042, 0x00, 0x08, 0xfb },
{ 0xd043, 0x00, 0x02, 0x01 },
{ 0xd045, 0x01, 0x01, 0x00 },
{ 0x9bcf, 0x00, 0x01, 0x01 },
{ 0xd045, 0x02, 0x01, 0x01 },
{ 0xd04f, 0x00, 0x08, 0x9a },
{ 0xd050, 0x00, 0x01, 0x01 },
{ 0xd051, 0x00, 0x08, 0x5a },
{ 0xd052, 0x00, 0x01, 0x01 },
{ 0xd053, 0x00, 0x08, 0x50 },
{ 0xd054, 0x00, 0x08, 0x46 },
{ 0x9bd7, 0x00, 0x08, 0x0a },
{ 0x9bd8, 0x00, 0x08, 0x14 },
{ 0x9bd9, 0x00, 0x08, 0x08 },
{ 0x9bd0, 0x00, 0x08, 0x93 },
{ 0x9be4, 0x00, 0x08, 0xfe },
{ 0x9bbd, 0x00, 0x08, 0x63 },
{ 0x9be2, 0x00, 0x08, 0xfe },
{ 0x9bee, 0x00, 0x01, 0x01 },
};

/* QT1010 tuner init
[crope@localhost Files]$ hexdump -s 0x0024158 -n 432 \
-e '1/2 "{ 0x%04x, " 2/1 "0x%02x, " 1/1 " 0x%02x }, " 1/1 "\n"' AF15BDA.sys
*/
static struct regdesc qt1010_tuner_init[] = {
{ 0x9bd5, 0x00, 0x08, 0x01 },
{ 0x9bd6, 0x00, 0x08, 0x09 },
{ 0xd1a0, 0x01, 0x01, 0x01 },
{ 0xd000, 0x00, 0x01, 0x01 },
{ 0xd000, 0x01, 0x01, 0x00 },
{ 0xd001, 0x01, 0x01, 0x01 },
{ 0xd001, 0x00, 0x01, 0x00 },
{ 0xd001, 0x05, 0x01, 0x00 },
{ 0xd002, 0x00, 0x05, 0x19 },
{ 0xd003, 0x00, 0x05, 0x1a },
{ 0xd004, 0x00, 0x05, 0x19 },
{ 0xd005, 0x00, 0x05, 0x1a },
{ 0xd00e, 0x00, 0x05, 0x10 },
{ 0xd00f, 0x00, 0x03, 0x04 },
{ 0xd00f, 0x03, 0x03, 0x05 },
{ 0xd010, 0x00, 0x03, 0x04 },
{ 0xd010, 0x03, 0x03, 0x05 },
{ 0xd016, 0x04, 0x04, 0x03 },
{ 0xd01f, 0x00, 0x06, 0x0a },
{ 0xd020, 0x00, 0x06, 0x0a },
{ 0x9bda, 0x00, 0x08, 0x01 },
{ 0x9be3, 0x00, 0x08, 0x01 },
{ 0xd015, 0x00, 0x08, 0x46 },
{ 0xd016, 0x00, 0x01, 0x00 },
{ 0xd044, 0x00, 0x08, 0x46 },
{ 0xd045, 0x00, 0x01, 0x00 },
{ 0x9bbe, 0x00, 0x01, 0x01 },
{ 0x9bcc, 0x00, 0x01, 0x01 },
{ 0x9bb9, 0x00, 0x08, 0x00 },
{ 0x9bcd, 0x00, 0x08, 0x28 },
{ 0x9bff, 0x00, 0x08, 0x20 },
{ 0xd008, 0x00, 0x08, 0x0f },
{ 0xd009, 0x00, 0x02, 0x02 },
{ 0xd006, 0x00, 0x08, 0x99 },
{ 0xd007, 0x00, 0x02, 0x01 },
{ 0xd00c, 0x00, 0x08, 0x0f },
{ 0xd00d, 0x00, 0x02, 0x02 },
{ 0xd00a, 0x00, 0x08, 0x50 },
{ 0xd00b, 0x00, 0x02, 0x01 },
{ 0x9bc7, 0x00, 0x08, 0x00 },
{ 0x9bc8, 0x00, 0x08, 0x00 },
{ 0x9bc3, 0x00, 0x08, 0x0f },
{ 0x9bc4, 0x00, 0x08, 0x02 },
{ 0x9bc5, 0x00, 0x08, 0x0f },
{ 0x9bc6, 0x00, 0x08, 0x02 },
{ 0x9bba, 0x00, 0x08, 0xc5 },
{ 0x9bc9, 0x00, 0x08, 0xff },
{ 0xd011, 0x00, 0x08, 0x58 },
{ 0xd012, 0x00, 0x02, 0x02 },
{ 0xd013, 0x00, 0x08, 0x89 },
{ 0xd014, 0x00, 0x02, 0x01 },
{ 0xd040, 0x00, 0x08, 0x58 },
{ 0xd041, 0x00, 0x02, 0x02 },
{ 0xd042, 0x00, 0x08, 0x89 },
{ 0xd043, 0x00, 0x02, 0x01 },
{ 0xd045, 0x01, 0x01, 0x00 },
{ 0x9bcf, 0x00, 0x01, 0x01 },
{ 0xd045, 0x02, 0x01, 0x01 },
{ 0xd04f, 0x00, 0x08, 0x9a },
{ 0xd050, 0x00, 0x01, 0x01 },
{ 0xd051, 0x00, 0x08, 0x5a },
{ 0xd052, 0x00, 0x01, 0x01 },
{ 0xd053, 0x00, 0x08, 0x50 },
{ 0xd054, 0x00, 0x08, 0x46 },
{ 0x9bd7, 0x00, 0x08, 0x0a },
{ 0x9bd8, 0x00, 0x08, 0x14 },
{ 0x9bd9, 0x00, 0x08, 0x08 },
{ 0x9bd0, 0x00, 0x08, 0xcd },
{ 0x9be4, 0x00, 0x08, 0xbb },
{ 0x9bbd, 0x00, 0x08, 0x93 },
{ 0x9be2, 0x00, 0x08, 0x80 },
{ 0x9bee, 0x00, 0x01, 0x01 },
};

/* TDA18271 tuner init
[crope@localhost Files]$ hexdump -s 0x0024670 -n 432 \
-e '1/2 "{ 0x%04x, " 2/1 "0x%02x, " 1/1 " 0x%02x }, " 1/1 "\n"' AF15BDA.sys
*/
static struct regdesc tda18271_tuner_init[] = {
{ 0x9bd5, 0x00, 0x08, 0x01 },
{ 0x9bd6, 0x00, 0x08, 0x04 },
{ 0xd1a0, 0x01, 0x01, 0x01 },
{ 0xd000, 0x00, 0x01, 0x01 },
{ 0xd000, 0x01, 0x01, 0x00 },
{ 0xd001, 0x01, 0x01, 0x01 },
{ 0xd001, 0x00, 0x01, 0x00 },
{ 0xd001, 0x05, 0x01, 0x00 },
{ 0xd002, 0x00, 0x05, 0x19 },
{ 0xd003, 0x00, 0x05, 0x1a },
{ 0xd004, 0x00, 0x05, 0x19 },
{ 0xd005, 0x00, 0x05, 0x1a },
{ 0xd00e, 0x00, 0x05, 0x10 },
{ 0xd00f, 0x00, 0x03, 0x04 },
{ 0xd00f, 0x03, 0x03, 0x05 },
{ 0xd010, 0x00, 0x03, 0x04 },
{ 0xd010, 0x03, 0x03, 0x05 },
{ 0xd016, 0x04, 0x04, 0x03 },
{ 0xd01f, 0x00, 0x06, 0x0a },
{ 0xd020, 0x00, 0x06, 0x0a },
{ 0x9bda, 0x00, 0x08, 0x01 },
{ 0x9be3, 0x00, 0x08, 0x01 },
{ 0xd1a0, 0x01, 0x01, 0x00 },
{ 0x9bbe, 0x00, 0x01, 0x01 },
{ 0x9bcc, 0x00, 0x01, 0x01 },
{ 0x9bb9, 0x00, 0x08, 0x00 },
{ 0x9bcd, 0x00, 0x08, 0x18 },
{ 0x9bff, 0x00, 0x08, 0x2c },
{ 0xd015, 0x00, 0x08, 0x46 },
{ 0xd016, 0x00, 0x01, 0x00 },
{ 0xd044, 0x00, 0x08, 0x46 },
{ 0xd045, 0x00, 0x01, 0x00 },
{ 0xd008, 0x00, 0x08, 0xdf },
{ 0xd009, 0x00, 0x02, 0x02 },
{ 0xd006, 0x00, 0x08, 0x44 },
{ 0xd007, 0x00, 0x02, 0x01 },
{ 0xd00c, 0x00, 0x08, 0x00 },
{ 0xd00d, 0x00, 0x02, 0x02 },
{ 0xd00a, 0x00, 0x08, 0xf6 },
{ 0xd00b, 0x00, 0x02, 0x01 },
{ 0x9bba, 0x00, 0x08, 0xf9 },
{ 0x9bc8, 0x00, 0x08, 0xaa },
{ 0x9bc3, 0x00, 0x08, 0xdf },
{ 0x9bc4, 0x00, 0x08, 0x02 },
{ 0x9bc5, 0x00, 0x08, 0x00 },
{ 0x9bc6, 0x00, 0x08, 0x02 },
{ 0x9bc9, 0x00, 0x08, 0xf0 },
{ 0xd011, 0x00, 0x08, 0x3c },
{ 0xd012, 0x00, 0x02, 0x01 },
{ 0xd013, 0x00, 0x08, 0xf7 },
{ 0xd014, 0x00, 0x02, 0x02 },
{ 0xd040, 0x00, 0x08, 0x0b },
{ 0xd041, 0x00, 0x02, 0x02 },
{ 0xd042, 0x00, 0x08, 0x4d },
{ 0xd043, 0x00, 0x02, 0x00 },
{ 0xd045, 0x01, 0x01, 0x00 },
{ 0x9bcf, 0x00, 0x01, 0x01 },
{ 0xd045, 0x02, 0x01, 0x01 },
{ 0xd04f, 0x00, 0x08, 0x9a },
{ 0xd050, 0x00, 0x01, 0x01 },
{ 0xd051, 0x00, 0x08, 0x5a },
{ 0xd052, 0x00, 0x01, 0x01 },
{ 0xd053, 0x00, 0x08, 0x50 },
{ 0xd054, 0x00, 0x08, 0x46 },
{ 0x9bd7, 0x00, 0x08, 0x0a },
{ 0x9bd8, 0x00, 0x08, 0x14 },
{ 0x9bd9, 0x00, 0x08, 0x08 },
{ 0x9bd0, 0x00, 0x08, 0xa8 },
{ 0x9be4, 0x00, 0x08, 0x7f },
{ 0x9bbd, 0x00, 0x08, 0xa8 },
{ 0x9be2, 0x00, 0x08, 0x20 },
{ 0x9bee, 0x00, 0x01, 0x01 },
};

#endif /* _AF9013_PRIV_ */
