/*
	Maxlinear MXL5003, MXL5005 Multi Mode tuner driver

	Copyright (C) Manu Abraham <abraham.manu@gmail.com>
	Copyright (C) Matthias Schwarzott <zzam@gentoo.org>

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __MXL500x_H
#define __MXL500x_H

enum mxl500x_master_control {
	MXL500x_LOAD_START	= 0xf2,
	MXL500x_POWER_DOWN	= 0x40,
	MXL500x_SYNTH_RST	= 0xb0,
	MXL500x_SEQ_OFF		= 0xf0,
};

/* for Analog mode */
enum mxl500x_if_mode {
	MXL500x_ZIF_MODE	= 0,
	MXL500x_LOWIF_MODE,
};

/* Tuner CLOCK Output mode */
enum mxl500x_clk_out {
	MXL_CLOCK_OUT_DISABLE	= 0,
	MXL_CLOCK_OUT_ENABLE,
};

/* Tuner On chip Pullup capacitor */
enum mxl500x_cap_sel {
	MXL_CAP_SEL_DISABLE	= 0,
	MXL_CAP_SEL_ENABLE,
};

/* Tuner Divider mode 4/16 MHz */
enum mxl500x_div_out {
	MXL_DIV_OUT_1		= 0,
	MXL_DIV_OUT_4
};

/* Tuner IF Output load resistor */
enum mxl500x_op_imp {
	OP_IMP_200E		= 0,
	OP_IMP_300E,
};

enum mxl500x_en_rssi {
	MXL_RSSI_DISABLE	= 0,
	MXL_RSSI_ENABLE,
};

enum mxl500x_tuner_mode {
	MXL500x_TUNER_ANALOG	= 0,
	MXL500x_TUNER_DIGITAL,
};

enum mxl500x_delsys {
	MXL500x_MODE_DVBT	= 1,
	MXL500x_MODE_ATSC,
	MXL500x_MODE_QAM
};

enum mxl500x_octf {
	MXL500x_OCTF_OFF	= 1,
	MXL500x_OCTF_C,
	MXL500x_OCTF_CH
};

struct mxl500x_config {
	enum mxl500x_delsys	delsys;
	enum mxl500x_octf	octf;

	u32 xtal_freq;
	u32 iflo_freq;
	u32 ref_freq;
	u8 rssi_ena;
	u8 addr;
};

#if defined(CONFIG_DVB_MXL500x) || (defined(CONFIG_DVB_MXL500x_MODULE) && defined(MODULE))
extern struct dvb_frontend *mxl500x_attach(struct dvb_frontend *fe,
					   const struct mxl500x_config *config,
					   struct i2c_adapter *i2c);
#else
static inline struct dvb_frontend *mxl500x_attach(struct dvb_frontend *fe,
						  const struct mxl500x_config *config,
						  struct i2c_adapter *i2c)
{
	printk(KERN_WARNING "%s: Driver disabled by Kconfig\n", __func__);
	return NULL;
}
#endif

#endif //__MXL500x_H
