/*
	Maxlinear MXL5003, MXL5005 Multi Mode tuner driver

	Copyright (C) Manu Abraham <abraham.manu@gmail.com>
	Copyright (C) Matthias Schwarzott <zzam@gentoo.org>

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __MXL500x_REG_H
#define __MXL500x_REG_H

#define MXL500x_GETFIELD(bitf, val)		((val >> MXL500x_OFFST_##bitf) &				\
						 ((1 << MXL500x_WIDTH_##bitf) - 1))

#define MXL500x_SETFIELD(bitf, mask, val)	(mask = (mask & (~(((1 << MXL500x_WIDTH_##bitf) - 1)	<<	\
							MXL500x_OFFST_##bitf))) | (val << MXL500x_OFFST_##bitf))

#define MXL500x_MSB(bitf, val)		(val >> MXL500x_WIDTH_##bitf)
#define MXL500x_LSB(bitf, val)		(val & ((1 << MXL500x_WIDTH_##bitf) - 1))

#define MXL500x_BYTE0(bitf, val)	((val & 0x000000ff)         & ((1 << MXL500x_WIDTH_##bitf) - 1))
#define MXL500x_BYTE1(bitf, val)	(((val & 0x0000ff00) >>  8) & ((1 << MXL500x_WIDTH_##bitf) - 1))
#define MXL500x_BYTE2(bitf, val)	(((val & 0x00ff0000) >> 16) & ((1 << MXL500x_WIDTH_##bitf) - 1))
#define MXL500x_BYTE3(bitf, val)	(((val & 0xff000000) >> 24) & ((1 << MXL500x_WIDTH_##bitf) - 1))

/* Master Control */
#define MXL500x_PWRUD1				9
#define MXL500x_WIDTH_PWRUD1_EN_ANALOG_REG		1
#define MXL500x_OFFST_PWRUD1_EN_ANALOG_REG		7
#define MXL500x_WIDTH_PWRUD1_ANALOG_RESET		1
#define MXL500x_OFFST_PWRUD1_ANALOG_RESET		6
#define MXL500x_WIDTH_PWRUD1_EN_MASTER_SYNTH		1
#define MXL500x_OFFST_PWRUD1_EN_MASTER_SYNTH		5
#define MXL500x_WIDTH_PWRUD1_EN_MASTER_SIGPATH		1
#define MXL500x_OFFST_PWRUD1_EN_MASTER_SIGPATH		4
#define MXL500x_WIDTH_PWRUD1_INIT_1			1
#define MXL500x_OFFST_PWRUD1_INIT_1			3
#define MXL500x_WIDTH_PWRUD1_AGC_EN_IF			1
#define MXL500x_OFFST_PWRUD1_AGC_EN_IF			2
#define MXL500x_WIDTH_PWRUD1_SEQUENCER_GO		1
#define MXL500x_OFFST_PWRUD1_SEQUENCER_GO		1
#define MXL500x_WIDTH_PWRUD1_INIT_0			1
#define MXL500x_OFFST_PWRUD1_INIT_0			0

/* Initialization controls
 * Filter control
 */
#define MXL500x_LPF1				53
#define MXL500x_WIDTH_LPF1_BB_ALPF_BANDSEL		3
#define MXL500x_OFFST_LPF1_BB_ALPF_BANDSEL		5
#define MXL500x_WIDTH_LPF1_BB_DLPF_BANDSEL		2
#define MXL500x_OFFST_LPF1_BB_DLPF_BANDSEL		3
#define MXL500x_WIDTH_LPF1_BB_MODE			1
#define MXL500x_OFFST_LPF1_BB_MODE			2
#define MXL500x_WIDTH_LPF1_BB_BUF_0			1
#define MXL500x_OFFST_LPF1_BB_BUF_0			1
#define MXL500x_WIDTH_LPF1_BB_BUF_0A			1
#define MXL500x_OFFST_LPF1_BB_BUF_0A			0

#define MXL500x_LPF2				59
#define MXL500x_WIDTH_LPF2_BB_INITSTATE_DLPF_TUNE	6
#define MXL500x_OFFST_LPF2_BB_INITSTATE_DLPF_TUNE	1
#define MXL500x_WIDTH_LPF2_BB_IQSWAP			1
#define MXL500x_OFFST_LPF2_BB_IQSWAP			0

/* Charge pump control */
#define MXL500x_CHP1				25
#define MXL500x_WIDTH_CHP1_EN_CHP_LIN_B			8
#define MXL500x_OFFST_CHP1_EN_CHP_LIN_B			0

/* AGC TOP control */
#define MXL500x_AGC1				76
#define MXL500x_WIDTH_AGC1_AGC_RF			4
#define MXL500x_OFFST_AGC1_AGC_RF			4
#define MXL500x_WIDTH_AGC1_AGC_IF			4
#define MXL500x_OFFST_AGC1_AGC_IF			0

/* IF Synthesizer / Xtal control */
#define MXL500x_IFSYN1				11
#define MXL500x_WIDTH_IFSYN1_INIT			1
#define MXL500x_OFFST_IFSYN1_INIT			7
#define MXL500x_WIDTH_IFSYN1_CHCAL_INT_MOD_IF		7
#define MXL500x_OFFST_IFSYN1_CHCAL_INT_MOD_IF		0

#define MXL500x_IFSYN2				12
#define MXL500x_WIDTH_IFSYN2_CHCAL_FRAC_MOD_IF_MSB	8
#define MXL500x_OFFST_IFSYN2_CHCAL_FRAC_MOD_IF_MSB	0

#define MXL500x_IFSYN3				13
#define MXL500x_WIDTH_IFSYN3_CHCAL_FRAC_MOD_IF_LSB	8
#define MXL500x_OFFST_IFSYN3_CHCAL_FRAC_MOD_IF_LSB	0

#define MXL500x_IFSYN4				43
#define MXL500x_WIDTH_IFSYN4_IF_DIVVAL			5
#define MXL500x_OFFST_IFSYN4_IF_DIVVAL			3
#define MXL500x_WIDTH_IFSYN4_INIT_1			1
#define MXL500x_OFFST_IFSYN4_INIT_1			2
#define MXL500x_WIDTH_IFSYN4_INIT_0			1
#define MXL500x_OFFST_IFSYN4_INIT_0			1
#define MXL500x_WIDTH_IFSYN4_IF_SEL_DBL			1
#define MXL500x_OFFST_IFSYN4_IF_SEL_DBL			0

#define MXL500x_IFSYN5				44
#define MXL500x_WIDTH_IFSYN5_IF_VCO_BIAS		6
#define MXL500x_OFFST_IFSYN5_IF_VCO_BIAS		2

/* IF upconverter control */
#define MXL500x_IFUP1				147
#define MXL500x_WIDTH_IFUP1_EN_AAF			1
#define MXL500x_OFFST_IFUP1_EN_AAF			7
#define MXL500x_WIDTH_IFUP1_EN_3P			1
#define MXL500x_OFFST_IFUP1_EN_3P			6
#define MXL500x_WIDTH_IFUP1_SEL_AAF_BAND		1
#define MXL500x_OFFST_IFUP1_SEL_AAF_BAND		5
#define MXL500x_WIDTH_IFUP1_DRV_RES_SEL			3
#define MXL500x_OFFST_IFUP1_DRV_RES_SEL			2
#define MXL500x_WIDTH_IFUP1_I_DRIVER			2
#define MXL500x_OFFST_IFUP1_I_DRIVER			0

#define MXL500x_IFUP2				156
#define MXL500x_WIDTH_IFUP2_INIT6			1
#define MXL500x_OFFST_IFUP2_INIT6			7
#define MXL500x_WIDTH_IFUP2_INIT5			1
#define MXL500x_OFFST_IFUP2_INIT5			6
#define MXL500x_WIDTH_IFUP2_INIT4			1
#define MXL500x_OFFST_IFUP2_INIT4			5
#define MXL500x_WIDTH_IFUP2_INIT3			1
#define MXL500x_OFFST_IFUP2_INIT3			4
#define MXL500x_WIDTH_IFUP2_INIT2			1
#define MXL500x_OFFST_IFUP2_INIT2			3
#define MXL500x_WIDTH_IFUP2_INIT1			1
#define MXL500x_OFFST_IFUP2_INIT1			2
#define MXL500x_WIDTH_IFUP2_INIT0			1
#define MXL500x_OFFST_IFUP2_INIT0			1
#define MXL500x_WIDTH_IFUP2_EN_AUX_3P			1
#define MXL500x_OFFST_IFUP2_EN_AUX_3P			0

/* Demodulator clock OUT/RSSI control */
#define MXL500x_DEMCLK				137
#define MXL500x_WIDTH_DEMCLK_SEQ_SEL4_16B		1
#define MXL500x_OFFST_DEMCLK_SEQ_SEL4_16B		7
#define MXL500x_WIDTH_DEMCLK_INIT_4			1
#define MXL500x_OFFST_DEMCLK_INIT_4			6
#define MXL500x_WIDTH_DEMCLK_INIT_3			1
#define MXL500x_OFFST_DEMCLK_INIT_3			5
#define MXL500x_WIDTH_DEMCLK_SEQ_ENCLK16_CLK_OUT	1
#define MXL500x_OFFST_DEMCLK_SEQ_ENCLK16_CLK_OUT	4
#define MXL500x_WIDTH_DEMCLK_SEQ_EXTDCCAL		1
#define MXL500x_OFFST_DEMCLK_SEQ_EXTDCCAL		3
#define MXL500x_WIDTH_DEMCLK_INIT_2			1
#define MXL500x_OFFST_DEMCLK_INIT_2			2
#define MXL500x_WIDTH_DEMCLK_INIT_1			1
#define MXL500x_OFFST_DEMCLK_INIT_1			1
#define MXL500x_WIDTH_DEMCLK_INIT_0			1
#define MXL500x_OFFST_DEMCLK_INIT_0			0

/* XTAL control */
#define MXL500x_XTAL1				91
#define MXL500x_WIDTH_XTAL1_INIT_6			1
#define MXL500x_OFFST_XTAL1_INIT_6			7
#define MXL500x_WIDTH_XTAL1_INIT_5			1
#define MXL500x_OFFST_XTAL1_INIT_5			6
#define MXL500x_WIDTH_XTAL1_XTAL_CAPSELECT		1
#define MXL500x_OFFST_XTAL1_XTAL_CAPSELECT		5
#define MXL500x_WIDTH_XTAL1_INIT_4			1
#define MXL500x_OFFST_XTAL1_INIT_4			4
#define MXL500x_WIDTH_XTAL1_INIT_3			1
#define MXL500x_OFFST_XTAL1_INIT_3			3
#define MXL500x_WIDTH_XTAL1_INIT_2			1
#define MXL500x_OFFST_XTAL1_INIT_2			2
#define MXL500x_WIDTH_XTAL1_INIT_1			1
#define MXL500x_OFFST_XTAL1_INIT_1			1
#define MXL500x_WIDTH_XTAL1_INIT_0			1
#define MXL500x_OFFST_XTAL1_INIT_0			0

#define MXL500x_XTAL2				32
#define MXL500x_WIDTH_XTAL2_TG_R_DIV			6
#define MXL500x_OFFST_XTAL2_TG_R_DIV			2
#define MXL500x_WIDTH_XTAL2_INIT			1
#define MXL500x_OFFST_XTAL2_INIT			1

/* RSSI control */
#define MXL500x_RSSI1				166
#define MXL500x_WIDTH_RSSI1_RFA_ENCLKRFAGC		1
#define MXL500x_OFFST_RSSI1_RFA_ENCLKRFAGC		7
#define MXL500x_WIDTH_RSSI1_INIT			1
#define MXL500x_OFFST_RSSI1_INIT			6
#define MXL500x_WIDTH_RSSI1_RFA_RSSI_REF		3
#define MXL500x_OFFST_RSSI1_RFA_RSSI_REF		3
#define MXL500x_WIDTH_RSSI1_RFA_RSSI_REFH		3
#define MXL500x_OFFST_RSSI1_RFA_RSSI_REFH		0

#define MXL500x_RSSI2				167
#define MXL500x_WIDTH_RSSI2_INIT_4			1
#define MXL500x_OFFST_RSSI2_INIT_4			7
#define MXL500x_WIDTH_RSSI2_INIT_3			1
#define MXL500x_OFFST_RSSI2_INIT_3			6
#define MXL500x_WIDTH_RSSI2_INIT_2			1
#define MXL500x_OFFST_RSSI2_INIT_2			5
#define MXL500x_WIDTH_RSSI2_INIT_1			1
#define MXL500x_OFFST_RSSI2_INIT_1			4
#define MXL500x_WIDTH_RSSI2_INIT_0			1
#define MXL500x_OFFST_RSSI2_INIT_0			3
#define MXL500x_WIDTH_RSSI2_RFA_RSSI_REFL		3
#define MXL500x_OFFST_RSSI2_RFA_RSSI_REFL		0

#define MXL500x_RSSI3				168
#define MXL500x_WIDTH_RSSI3_RFA_CEIL			4
#define MXL500x_OFFST_RSSI3_RFA_CEIL			4
#define MXL500x_WIDTH_RSSI3_RFA_FLR			4
#define MXL500x_OFFST_RSSI3_RFA_FLR			0

#define MXL500x_RSSI4				134
#define MXL500x_WIDTH_RSSI4_INIT_6			1
#define MXL500x_OFFST_RSSI4_INIT_6			7
#define MXL500x_WIDTH_RSSI4_INIT_5			1
#define MXL500x_OFFST_RSSI4_INIT_5			6
#define MXL500x_WIDTH_RSSI4_INIT_4			1
#define MXL500x_OFFST_RSSI4_INIT_4			5
#define MXL500x_WIDTH_RSSI4_INIT_3			1
#define MXL500x_OFFST_RSSI4_INIT_3			4
#define MXL500x_WIDTH_RSSI4_INIT_2			1
#define MXL500x_OFFST_RSSI4_INIT_2			3
#define MXL500x_WIDTH_RSSI4_SEQ_EXTSYNTHCALIF		1
#define MXL500x_OFFST_RSSI4_SEQ_EXTSYNTHCALIF		2
#define MXL500x_WIDTH_RSSI4_INIT_1			1
#define MXL500x_OFFST_RSSI4_INIT_1			1
#define MXL500x_WIDTH_RSSI4_INIT_0			1
#define MXL500x_OFFST_RSSI4_INIT_0			0

#define MXL500x_RSSI5				77
#define MXL500x_WIDTH_RSSI5_AGC_EN_RSSI			1
#define MXL500x_OFFST_RSSI5_AGC_EN_RSSI			7
#define MXL500x_WIDTH_RSSI5_INIT_6			1
#define MXL500x_OFFST_RSSI5_INIT_6			6
#define MXL500x_WIDTH_RSSI5_INIT_5			1
#define MXL500x_OFFST_RSSI5_INIT_5			5
#define MXL500x_WIDTH_RSSI5_INIT_4			1
#define MXL500x_OFFST_RSSI5_INIT_4			4
#define MXL500x_WIDTH_RSSI5_INIT_3			1
#define MXL500x_OFFST_RSSI5_INIT_3			3
#define MXL500x_WIDTH_RSSI5_INIT_2			1
#define MXL500x_OFFST_RSSI5_INIT_2			2
#define MXL500x_WIDTH_RSSI5_INIT_1			1
#define MXL500x_OFFST_RSSI5_INIT_1			1
#define MXL500x_WIDTH_RSSI5_INIT_0			1
#define MXL500x_OFFST_RSSI5_INIT_0			0

/* miscellaneous control */
#define MXL500x_MISC1				56
#define MXL500x_WIDTH_MISC1_INIT_6			1
#define MXL500x_OFFST_MISC1_INIT_6			7
#define MXL500x_WIDTH_MISC1_INIT_5			1
#define MXL500x_OFFST_MISC1_INIT_5			6
#define MXL500x_WIDTH_MISC1_INIT_4			1
#define MXL500x_OFFST_MISC1_INIT_4			5
#define MXL500x_WIDTH_MISC1_INIT_3			1
#define MXL500x_OFFST_MISC1_INIT_3			4
#define MXL500x_WIDTH_MISC1_OVERRIDE1			1
#define MXL500x_OFFST_MISC1_OVERRIDE1			3
#define MXL500x_WIDTH_MISC1_INIT_2			1
#define MXL500x_OFFST_MISC1_INIT_2			2
#define MXL500x_WIDTH_MISC1_INIT_1			1
#define MXL500x_OFFST_MISC1_INIT_1			1
#define MXL500x_WIDTH_MISC1_INIT_0			1
#define MXL500x_OFFST_MISC1_INIT_0			0

#define MXL500x_MISC2				135
#define MXL500x_WIDTH_MISC2_INIT_6			1
#define MXL500x_OFFST_MISC2_INIT_6			7
#define MXL500x_WIDTH_MISC2_INIT_5			1
#define MXL500x_OFFST_MISC2_INIT_5			6
#define MXL500x_WIDTH_MISC2_INIT_4			1
#define MXL500x_OFFST_MISC2_INIT_4			5
#define MXL500x_WIDTH_MISC2_INIT_3			1
#define MXL500x_OFFST_MISC2_INIT_3			4
#define MXL500x_WIDTH_MISC2_INIT_2			1
#define MXL500x_OFFST_MISC2_INIT_2			3
#define MXL500x_WIDTH_MISC2_INIT_1			1
#define MXL500x_OFFST_MISC2_INIT_1			2
#define MXL500x_WIDTH_MISC2_INIT_0			1
#define MXL500x_OFFST_MISC2_INIT_0			1
#define MXL500x_WIDTH_MISC2_SEQ_EXTIQFSMPULSE		1
#define MXL500x_OFFST_MISC2_SEQ_EXTIQFSMPULSE		0

/* Down converter control/initialization */
#define MXL500x_DC1				68
#define MXL500x_WIDTH_DC1_DN_POLY			2
#define MXL500x_OFFST_DC1_DN_POLY			6
#define MXL500x_WIDTH_DC1_DN_CAP_RFLPF_1		6
#define MXL500x_OFFST_DC1_DN_CAP_RFLPF_1		0

#define MXL500x_DC2				69
#define MXL500x_WIDTH_DC2_DN_CAP_RFLPF_0		3
#define MXL500x_OFFST_DC2_DN_CAP_RFLPF_0		5
#define MXL500x_WIDTH_DC2_DN_SEL_FREQ			3
#define MXL500x_OFFST_DC2_DN_SEL_FREQ			2
#define MXL500x_WIDTH_DC2_INIT_1			1
#define MXL500x_OFFST_DC2_INIT_1			1
#define MXL500x_WIDTH_DC2_INIT_0			1
#define MXL500x_OFFST_DC2_INIT_0			0

#define MXL500x_DC3				70
#define MXL500x_WIDTH_DC3_DN_RFGAIN			2
#define MXL500x_OFFST_DC3_DN_RFGAIN			6
#define MXL500x_WIDTH_DC3_DN_EN_VHFUHFBAR		1
#define MXL500x_OFFST_DC3_DN_EN_VHFUHFBAR		5
#define MXL500x_WIDTH_DC3_DN_IQTNGBFBIAS_BST		1
#define MXL500x_OFFST_DC3_DN_IQTNGBFBIAS_BST		4
#define MXL500x_WIDTH_DC3_DN_IQTNBUF_AMP		4
#define MXL500x_OFFST_DC3_DN_IQTNBUF_AMP		0

#define MXL500x_DC4				73
#define MXL500x_WIDTH_DC4_DN_IQTN_AMP_CUT		1
#define MXL500x_OFFST_DC4_DN_IQTN_AMP_CUT		7
#define MXL500x_WIDTH_DC4_DN_GAIN_ADJUST		3
#define MXL500x_OFFST_DC4_DN_GAIN_ADJUST		4

/* RF synthesizer control */
#define MXL500x_RFSYN1				14
#define MXL500x_WIDTH_RFSYN1_CHCAL_EN_INT_RF		1
#define MXL500x_OFFST_RFSYN1_CHCAL_EN_INT_RF		7
#define MXL500x_WIDTH_RFSYN1_CHCAL_INT_MOD_RF		6
#define MXL500x_OFFST_RFSYN1_CHCAL_INT_MOD_RF		0

#define MXL500x_RFSYN2				15
#define MXL500x_WIDTH_RFSYN2_CHCAL_FRAC_MOD_RF_2	8
#define MXL500x_OFFST_RFSYN2_CHCAL_FRAC_MOD_RF_2	0

#define MXL500x_RFSYN3				16
#define MXL500x_WIDTH_RFSYN3_CHCAL_FRAC_MOD_RF_1	8
#define MXL500x_OFFST_RFSYN3_CHCAL_FRAC_MOD_RF_1	0

#define MXL500x_RFSYN4				17
#define MXL500x_WIDTH_RFSYN4_CHCAL_FRAC_MOD_RF_0	2
#define MXL500x_OFFST_RFSYN4_CHCAL_FRAC_MOD_RF_0	6
#define MXL500x_WIDTH_RFSYN4_OVERRIDE2			1
#define MXL500x_OFFST_RFSYN4_OVERRIDE2			5

#define MXL500x_RFSYN5				110
#define MXL500x_WIDTH_RFSYN5_RFSYN_VCO_BIAS		6
#define MXL500x_OFFST_RFSYN5_RFSYN_VCO_BIAS		2
#define MXL500x_WIDTH_RFSYN5_RFSYN_RF_DIV_BIAS		2
#define MXL500x_OFFST_RFSYN5_RFSYN_RF_DIV_BIAS		0

#define MXL500x_RFSYN6				111
#define MXL500x_WIDTH_RFSYN6_RFSYN_SEL_VCO_OUT		1
#define MXL500x_OFFST_RFSYN6_RFSYN_SEL_VCO_OUT		7
#define MXL500x_WIDTH_RFSYN6_RFSYN_SEL_VCO_HI		1
#define MXL500x_OFFST_RFSYN6_RFSYN_SEL_VCO_HI		6
#define MXL500x_WIDTH_RFSYN6_RFSYN_SEL_DIVM		1
#define MXL500x_OFFST_RFSYN6_RFSYN_SEL_DIVM		5
#define MXL500x_WIDTH_RFSYN6_RFSYN_EN_OUTMUX		1
#define MXL500x_OFFST_RFSYN6_RFSYN_EN_OUTMUX		4
#define MXL500x_WIDTH_RFSYN6_OVERRIDE3			1
#define MXL500x_OFFST_RFSYN6_OVERRIDE3			3

#define MXL500x_RFSYN7				112
#define MXL500x_WIDTH_RFSYN7_OVERRIDE4			1
#define MXL500x_OFFST_RFSYN7_OVERRIDE4			7
#define MXL500x_WIDTH_RFSYN7_INIT_1			1
#define MXL500x_OFFST_RFSYN7_INIT_1			6
#define MXL500x_WIDTH_RFSYN7_INIT_0			1
#define MXL500x_OFFST_RFSYN7_INIT_0			5
#define MXL500x_WIDTH_RFSYN7_RFSYN_LPF_R		5
#define MXL500x_OFFST_RFSYN7_RFSYN_LPF_R		0

#define MXL500x_RFSYN8				22
#define MXL500x_WIDTH_RFSYN8_RFSYN_CHP_GAIN		4
#define MXL500x_OFFST_RFSYN8_RFSYN_CHP_GAIN		4
#define MXL500x_WIDTH_RFSYN8_INIT			1
#define MXL500x_OFFST_RFSYN8_INIT			3
#define MXL500x_WIDTH_RFSYN8_RFSYN_EN_CHP_HIGAIN	1
#define MXL500x_OFFST_RFSYN8_RFSYN_EN_CHP_HIGAIN	2
#define MXL500x_WIDTH_RFSYN8_RFSYN_R_DIV		2
#define MXL500x_OFFST_RFSYN8_RFSYN_R_DIV		0

/* IQ calibration synthesizer control */
#define MXL500x_IQCALSYN1			106
#define MXL500x_WIDTH_IQCALSYN1_TG_VCO_BIAS		6
#define MXL500x_OFFST_IQCALSYN1_TG_VCO_BIAS		2
#define MXL500x_WIDTH_IQCALSYN1_TG_LO_SELVAL_1		2
#define MXL500x_OFFST_IQCALSYN1_TG_LO_SELVAL_1		0

#define MXL500x_IQCALSYN2			107
#define MXL500x_WIDTH_IQCALSYN2_TG_LO_SELVAL_0		1
#define MXL500x_OFFST_IQCALSYN2_TG_LO_SELVAL_0		7
#define MXL500x_WIDTH_IQCALSYN2_TG_LO_DIVVAL		4
#define MXL500x_OFFST_IQCALSYN2_TG_LO_DIVVAL		3
#define MXL500x_WIDTH_IQCALSYN2_INIT_2			1
#define MXL500x_OFFST_IQCALSYN2_INIT_2			2
#define MXL500x_WIDTH_IQCALSYN2_INIT_1			1
#define MXL500x_OFFST_IQCALSYN2_INIT_1			1
#define MXL500x_WIDTH_IQCALSYN2_INIT_0			1
#define MXL500x_OFFST_IQCALSYN2_INIT_0			0

#define MXL500x_IQCALSYN3			108
#define MXL500x_WIDTH_IQCALSYN3_INIT_2			1
#define MXL500x_OFFST_IQCALSYN3_INIT_2			7
#define MXL500x_WIDTH_IQCALSYN3_INIT_1			1
#define MXL500x_OFFST_IQCALSYN3_INIT_1			6
#define MXL500x_WIDTH_IQCALSYN3_INIT_0			1
#define MXL500x_OFFST_IQCALSYN3_INIT_0			5
#define MXL500x_WIDTH_IQCALSYN3_TG_DIV_VAL		5
#define MXL500x_OFFST_IQCALSYN3_TG_DIV_VAL		0

#define MXL500x_IQCALSYN4			109
#define MXL500x_WIDTH_IQCALSYN4_TG_DIV_VAL		6
#define MXL500x_OFFST_IQCALSYN4_TG_DIV_VAL		2
#define MXL500x_WIDTH_IQCALSYN4_INIT_1			1
#define MXL500x_OFFST_IQCALSYN4_INIT_1			1
#define MXL500x_WIDTH_IQCALSYN4_INIT_0			1
#define MXL500x_OFFST_IQCALSYN4_INIT_0			0

/* DAC control */
#define MXL500x_DAC1				92
#define MXL500x_WIDTH_DAC1_DAC_DIN_A			6
#define MXL500x_OFFST_DAC1_DAC_DIN_A			2

#define MXL500x_DAC2				93
#define MXL500x_WIDTH_DAC2_DAC_DIN_B			6
#define MXL500x_OFFST_DAC2_DAC_DIN_B			2
#define MXL500x_WIDTH_DAC2_DAC_A_ENABLE			1
#define MXL500x_OFFST_DAC2_DAC_A_ENABLE			1
#define MXL500x_WIDTH_DAC2_DAC_B_ENABLE			1
#define MXL500x_OFFST_DAC2_DAC_B_ENABLE			0

/* Miscellaneous tuning control */
#define MXL500x_MISC_TUNE1			136
#define MXL500x_WIDTH_MISC_TUNE1_SEQ_FSM_PULSE		1
#define MXL500x_OFFST_MISC_TUNE1_SEQ_FSM_PULSE		7
#define MXL500x_WIDTH_MISC_TUNE1_INIT_6			1
#define MXL500x_OFFST_MISC_TUNE1_INIT_6			6
#define MXL500x_WIDTH_MISC_TUNE1_INIT_5			1
#define MXL500x_OFFST_MISC_TUNE1_INIT_5			5
#define MXL500x_WIDTH_MISC_TUNE1_INIT_4			1
#define MXL500x_OFFST_MISC_TUNE1_INIT_4			4
#define MXL500x_WIDTH_MISC_TUNE1_INIT_3			1
#define MXL500x_OFFST_MISC_TUNE1_INIT_3			3
#define MXL500x_WIDTH_MISC_TUNE1_INIT_2			1
#define MXL500x_OFFST_MISC_TUNE1_INIT_2			2
#define MXL500x_WIDTH_MISC_TUNE1_INIT_1			1
#define MXL500x_OFFST_MISC_TUNE1_INIT_1			1
#define MXL500x_WIDTH_MISC_TUNE1_INIT_0			1
#define MXL500x_OFFST_MISC_TUNE1_INIT_0			0

#define MXL500x_MISC_TUNE2			138
#define MXL500x_WIDTH_MISC_TUNE2_INIT_6			1
#define MXL500x_OFFST_MISC_TUNE2_INIT_6			7
#define MXL500x_WIDTH_MISC_TUNE2_INIT_5			1
#define MXL500x_OFFST_MISC_TUNE2_INIT_5			6
#define MXL500x_WIDTH_MISC_TUNE2_INIT_4			1
#define MXL500x_OFFST_MISC_TUNE2_INIT_4			5
#define MXL500x_WIDTH_MISC_TUNE2_SEQ_EXTPOWERUP		1
#define MXL500x_OFFST_MISC_TUNE2_SEQ_EXTPOWERUP		4
#define MXL500x_WIDTH_MISC_TUNE2_INIT_3			1
#define MXL500x_OFFST_MISC_TUNE2_INIT_3			3
#define MXL500x_WIDTH_MISC_TUNE2_INIT_2			1
#define MXL500x_OFFST_MISC_TUNE2_INIT_2			2
#define MXL500x_WIDTH_MISC_TUNE2_INIT_1			1
#define MXL500x_OFFST_MISC_TUNE2_INIT_1			1
#define MXL500x_WIDTH_MISC_TUNE2_INIT_0			1
#define MXL500x_OFFST_MISC_TUNE2_INIT_0			0

#define MXL500x_MISC_TUNE3			149
#define MXL500x_WIDTH_MISC_TUNE3_GPIO_4B		1
#define MXL500x_OFFST_MISC_TUNE3_GPIO_4B		7
#define MXL500x_WIDTH_MISC_TUNE3_GPIO_3B		1
#define MXL500x_OFFST_MISC_TUNE3_GPIO_3B		6
#define MXL500x_WIDTH_MISC_TUNE3_GPIO_4			1
#define MXL500x_OFFST_MISC_TUNE3_GPIO_4			5
#define MXL500x_WIDTH_MISC_TUNE3_GPIO_3			1
#define MXL500x_OFFST_MISC_TUNE3_GPIO_3			4
#define MXL500x_WIDTH_MISC_TUNE3_GPIO_1B		1
#define MXL500x_OFFST_MISC_TUNE3_GPIO_1B		3
#define MXl500x_WIDTH_MISC_TUNE3_INIT_1			1
#define MXl500x_OFFST_MISC_TUNE3_INIT_1			1
#define MXl500x_WIDTH_MISC_TUNE3_INIT_0			1
#define MXl500x_OFFST_MISC_TUNE3_INIT_0			0

#endif //__MXL500x_REG_H
